package de.nwsnet.homework.LocalHostInfo;

/*
 * Copyright (c) 2003, 2003 Jochen Kupperschmidt <jochen@kupperschmidt.de>
 * Released under the terms of the GNU General Public License
 *    _                               _
 *   | |_ ___ _____ ___ _ _ _ ___ ___| |_
 *   |   | . |     | ._| | | | . |  _| . /
 *   |_|_|___|_|_|_|___|_____|___|_| |_|_\
 *     http://homework.nwsnet.de/
 */

import java.awt.BorderLayout;
import java.net.InetAddress;
import java.net.NetworkInterface;
import java.net.SocketException;
import java.util.Enumeration;

import javax.swing.BorderFactory;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeCellRenderer;

/**
 * A panel containing network interfaces as tree.
 *
 * @author  <a href="mailto:jochen@kupperschmidt.de">Jochen Kupperschmidt</a>
 * @version 28-Mar-2003
 */
class InterfacesPanel extends JPanel {

	public InterfacesPanel(Frontend frontend) {
		// create interface tree
        DefaultMutableTreeNode treeRoot =
            new DefaultMutableTreeNode("Network Interfaces");

		// fetch interfaces
		DefaultMutableTreeNode nicNode;
        try {
            Enumeration nis = NetworkInterface.getNetworkInterfaces();
	        while (nis.hasMoreElements()) {
	            NetworkInterface ni = (NetworkInterface) nis.nextElement();
	            nicNode =
	                new DefaultMutableTreeNode(
	                    ni.getName() + " [ " + ni.getDisplayName() + " ]");
	            treeRoot.add(nicNode);
	
	            // fetch addresses for this interface
	            Enumeration nias = ni.getInetAddresses();
	            if (!nias.hasMoreElements()) {
	                nicNode.add(
	                    new DefaultMutableTreeNode("no addresses found"));
	            } else {
	                while (nias.hasMoreElements()) {
		                InetAddress nia = (InetAddress) nias.nextElement();
	    	            nicNode.add(
	        	            new DefaultMutableTreeNode(
	            	            nia.getHostAddress()
	                	            + " [ " + nia.getHostName() + " ]"));
		            }
	            }
			}
        } catch (SocketException e) {
			JOptionPane.showMessageDialog(this, "Error: " + e.getMessage());
        }

		JTree tree = new JTree(treeRoot);
		tree.setRootVisible(false);

		// create tree renderer
		DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer();
		renderer.setOpenIcon(frontend.getNicIcon());
		renderer.setClosedIcon(frontend.getNicIcon());
		renderer.setLeafIcon(null);
		tree.setCellRenderer(renderer);

		// expand all rows
		for (int row = 0; row < tree.getRowCount(); row++) {
			tree.expandRow(row);
		}

		// add interfaces tree to panel
        setBorder(
            BorderFactory.createCompoundBorder(
                BorderFactory.createTitledBorder(
                    BorderFactory.createEtchedBorder(),
                    "Interfaces"),
                BorderFactory.createEmptyBorder(0, 4, 4, 4)));
        setLayout(new BorderLayout());
		add(new JScrollPane(tree), BorderLayout.CENTER);
	}
}
